@@ -3,7 +3,7 @@ package MD5Check;
 use strict;
 use warnings;
 use utf8;
-
+use Digest::MD5;
 require Exporter;
 
 our @ISA     = qw(Exporter);
@@ -17,38 +17,38 @@ MD5Check -  Use it for init Web files's md5 values of your site(or other dir), a
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 =head1 SYNOPSIS
 
-    e MD5Check;
+    use MD5Check;
 
 ## 初始化目录md5值,参数为要监控的目录
 
     my $mydir=shift;
-    md5init($mydir);
+    print md5init($mydir);
 
 ## 对目录文件进行检查，只需输入之前保存的md5 文件值。
 
     use MD5Check;
     my $mydir=shift;
-    md5check($mydir);
+    print md5check($mydir);
 
     # oneliner，perl单行程序实现功能。
 
 需要安装该模块，简单通过 cpanm MD5Check 安装。
 
-    $ perl -MMD5Check -e 'md5init("/web")' >file
-    $ perl -MMD5Check -e 'md5check(file) perl -MMD5Check -e 'md5check(file)'..
+    $ perl -MMD5Check -e 'print md5init("/web")' >file
+    $ perl -MMD5Check -e 'print md5check(file) perl -MMD5Check -e 'md5check(file)'..
 
 
 =cut
-
+my $DEBUG=0;
 sub md5_sum {
 
  my ($file_name,$mode)=@_;
@@ -65,54 +65,57 @@ sub md5_sum {
 sub md5check {
 my $file=shift;
 open(my $fd, '<',$file) or die "$file: $!\n";
-print $file;
+my $res.=$file."\n";
 while (<$fd>){
         my ($name, $sum) = split /\s+/;
         $name =~ s/^\*//;
         if ($sum eq md5_sum($name,1)){
-                print "$name OK\n";
+                $res.= "$name OK\n";
         }
         else{
-          print "$name FAILED\n";
+          $res.= "$name FAILED\n";
         }
 }
 
 close $fd;
 
+return $res;
 }
 # 遍历目录计算md5值
 sub md5init {
 
     my $fd=shift;
     my $md5value;
+    my $res;
     if ( -f $fd ){
             if ( -T $fd ) {
                 #print "按照文本模式进行计算MD5!\n";
                 $md5value =md5_sum($fd,0);
-                print "$fd\t$md5value\n";
+                $res.= "$fd\t$md5value\n";
             }elsif( -B $fd ){
                 #print "二进制文件用binmod计算MD5!\n";
                 $md5value =md5_sum($fd,1);
-                print "$fd\t$md5value\n";
+                $res.= "$fd\t$md5value\n";
             }else{
                 #print "其他文件，按照bimmod计算!\n";
                 $md5value = md5_sum($fd,1);
-                print "$fd\t$md5value\n";
+                $res.= "$fd\t$md5value\n";
             }
      }
      elsif( -d $fd ){
         my $file_md5;
-      # print "开始验证目录下所有文件:\n";
+      print "开始验证目录下所有文件:\n";
        opendir (my $DH,$fd) or die "Can't open dir $fd: $!";
          for(readdir $DH ){
          my $file=$fd.'/'.$_;
       # 上级目录..，本目录. 以及连接文件跳过
          next if ($file =~ m{/.$} || $file =~ m{/..$} || -l $file );
-         md5init($file);
+         $res.=md5init($file);
+          print "Debug::",$res if $DEBUG;
         }
        closedir $DH;
     }
-
+return $res;
 }
 
 1;
@@ -127,13 +130,17 @@ MD5Check is not standardized. This module is far from complete.
 
 =head2 IMPLEMENTATION
 
-    use MD5Check;
-    my $mydir=shift;
-    md5init($mydir);
+#Init the web dir md5 values
 
     use MD5Check;
     my $mydir=shift;
-    md5check($mydir);
+    print  md5init($mydir);
+=====================
+#check files 
+
+    use MD5Check;
+    my $mydir=shift;
+    print md5check($mydir);
 
 =head1 Git repo
 
